==> bacula-2.4.4-b2.tar.gz: bacula-2.4.4-b2/src/win32/dird/who.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation, which is 
   listed in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of John Walker.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 * Kern Sibbald, August 2007
 *
 * Version $Id: who.h 5358 2007-08-15 16:54:21Z kerns $
 *
 * This file is pulled in by certain generic routines in libwin32
 *   to define the names of the daemon that is being built.
 */

#define APP_NAME "Bacula-dir"
#define LC_APP_NAME "bacula-dir"
#define APP_DESC "Bacula Director Service"

#define terminate_app(x) terminate_dird(x)
extern void terminate_dird(int sig);

#define VSSInit()

==> bacula-3.0.2.tar.gz: bacula-3.0.2/src/win32/dird/who.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation, which is 
   listed in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 * Kern Sibbald, August 2007
 *
 * Version $Id: who.h 7380 2008-07-14 10:42:59Z kerns $
 *
 * This file is pulled in by certain generic routines in libwin32
 *   to define the names of the daemon that is being built.
 */

#define APP_NAME "Bacula-dir"
#define LC_APP_NAME "bacula-dir"
#define APP_DESC "Bacula Director Service"

#define terminate_app(x) terminate_dird(x)
extern void terminate_dird(int sig);

#define VSSInit()
